@@ -1,6 +1,6 @@
 package Sub::Spec::CmdLine;
 BEGIN {
-  $Sub::Spec::CmdLine::VERSION = '0.19';
+  $Sub::Spec::CmdLine::VERSION = '0.21';
 }
 # ABSTRACT: Access Perl subs via command line
 
@@ -88,8 +88,8 @@ sub parse_argv {
         die "Incorrect command-line options/arguments\n" if $opts->{strict};
     }
 
-    $log->tracef("tmp args result (after getoptions): %s, argv: %s",
-                 $args, $argv);
+    #$log->tracef("tmp args result (after getoptions): %s, argv: %s",
+    #             $args, $argv);
 
     # parse YAML in opt values
     for my $k (keys %$args) {
@@ -140,8 +140,8 @@ sub parse_argv {
         }
     }
 
-    $log->tracef("tmp args result (after arg_pos processing): %s, argv: %s",
-                 $args, $argv);
+    #$log->tracef("tmp args result (after arg_pos processing): %s, argv: %s",
+    #             $args, $argv);
     if (@$argv) {
         die "Error: extra argument(s): ".join(", ", @$argv)."\n"
             if $opts->{strict};
@@ -159,7 +159,7 @@ sub parse_argv {
         delete $args->{$_} unless defined($args->{$_});
     }
 
-    $log->tracef("<- parse_argv(), args=%s", $args);
+    $log->tracef("<- parse_argv(), args=%s, remaining argv=%s", $args, $argv);
     $args;
 }
 
@@ -600,7 +600,7 @@ sub run {
 
             if ($sub) {
                 no strict 'refs';
-                my $subs = \%{$module."::SUBS"};
+                my $subs = \%{$module."::SPEC"};
                 $spec = $subs->{$sub};
                 die "Can't find spec for sub $module\::$sub\n"
                     unless $spec || $ENV{COMP_LINE};
@@ -637,7 +637,8 @@ sub run {
             subcommand_name => $subc_name,
         );
         $log->tracef("completion result: %s", \@res);
-        print map {"$_\n"} @res;
+        print map {Sub::Spec::BashComplete::_add_slashes($_), "\n"} @res;
+        #print map {"$_\n"} @res;
         if ($exit) { exit 0 } else { return 0 }
     }
 
@@ -718,16 +719,16 @@ Sub::Spec::CmdLine - Access Perl subs via command line
 
 =head1 VERSION
 
-version 0.19
+version 0.21
 
 =head1 SYNOPSIS
 
 In your module:
 
  package YourModule;
- our %SUBS;
+ our %SPEC;
 
- $SUBS{foo} = {
+ $SPEC{foo} = {
      summary => 'Foo!',
      args => {
          arg  => ...,
@@ -787,8 +788,8 @@ None of the functions are exported by default, but they are exportable.
 
 =head2 parse_argv(\@argv, $sub_spec[, \%opts]) => \%args
 
-Parse command line argument @argv into hash %args, suitable for passing into
-subs.
+Using information in spec's B<args> clause, parse command line argument @argv
+into hash %args, suitable for passing into subs.
 
 Uses Getopt::Long to parse the result.
 
@@ -808,6 +809,52 @@ If set to 0, will still return parsed argv even if there are errors.
 
 =back
 
+=head3 How parse_argv() translates the args spec clause
+
+Bool types can be specified using
+
+ --argname
+
+or
+
+ --noargname
+
+All the other types can be specified using
+
+ --argname VALUE
+
+or
+
+ --argname=VALUE
+
+where I<VALUE> is assumed to be in YAML markup, except when YAML loading failed
+then it will be assumed to be a string literal. Example:
+
+ --argname '[1, 2, 3]'
+
+then $args{argname} will contain a hashref [1, 2, 3]. But with:
+
+ --argname '[1, 2, 3'
+
+then $args{argname} will contain a string '[1, 2, 3' since YAML parsing failed.
+
+parse_argv() also takes B<arg_pos> and B<arg_greedy> type clause in schema into
+account, for example:
+
+ $SPEC{multiply2} = {
+     summary => 'Multiply 2 numbers (a & b)',
+     args => {
+         a => ['num*' => {arg_pos=>0}],
+         b => ['num*' => {arg_pos=>1}],
+     }
+ }
+
+then on the command-line any of below is valid:
+
+ % multiply2 --a 2 --b 3
+ % multiply2 2 --b 3; # first non-option argument is fed into a (arg_pos=0)
+ % multiply2 2 3;     # first argument is fed into a, second into b (arg_pos=1)
+
 =head2 gen_usage($sub_spec) => TEXT
 
 Generate usage information for a sub (typically used for --help).
